#ifndef SVN_VERSION_H
#define SVN_VERSION_H

#define SVN_VERSION "d56d870a5e7dad6c9f1a8c3b1075f11844b87ca2 [/startdir/boinc] (archlinux:/build/boinc/src/boinc-nox [makepkg]) [Server-Release: server_release/1.x/1.x.0-3298-gd56d870a5e7dad6c9f1a8c3b1075f11844b87ca2]"
#define GIT_REVISION 0xd56d870a
#define GIT_DATE 1773710114
#define REPOSITORY__STARTDIR_BOINC 1

#endif
